Package: fxl
Type: Package
Title: 'fxl' Single Case Design Charting Package
Version: 1.7.3
Authors@R: person(given = "Shawn",
           family = "Gilroy",
           role = c("aut", "cre", "cph"),
           email = "sgilroy1@lsu.edu",
           comment = c(ORCID = "0000-0002-1097-8366"))
Suggests: covr, knitr, rmarkdown, testthat (>= 3.0.0), here, tidyverse,
        scales, dplyr
VignetteBuilder: knitr
Description: The 'fxl' Charting package is used to prepare and design single case design figures that are typically prepared in spreadsheet software. With 'fxl', there is no need to leave the R environment to prepare these works and many of the more unique conventions in single case experimental designs can be performed without the need for physically constructing features of plots (e.g., drawing annotations across plots). Support is provided for various different plotting arrangements (e.g., multiple baseline), annotations (e.g., brackets, arrows), and output formats (e.g., svg, rasters).
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.1), rlang
RoxygenNote: 7.2.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-01-21 20:23:23 UTC; shawn
Author: Shawn Gilroy [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-1097-8366>)
Maintainer: Shawn Gilroy <sgilroy1@lsu.edu>
Repository: CRAN
Date/Publication: 2026-01-21 20:40:09 UTC
Built: R 4.6.0; ; 2026-04-25 19:06:53 UTC; unix
