# Generated by roxygen2: do not edit by hand

S3method(print,fxl)
S3method(print,fxlsemilog)
export(cnvrt_coords)
export(draw_arrows)
export(draw_bar_support)
export(draw_brackets)
export(draw_cumsum_lines)
export(draw_cumsum_points)
export(draw_guide_line)
export(draw_label_facet)
export(draw_label_phase)
export(draw_legend)
export(draw_lines)
export(draw_points)
export(draw_rect)
export(draw_scr_criterion)
export(draw_scr_plines)
export(isValidAXSCharacter)
export(isValidAestheticMapping)
export(isValidCharacterVector)
export(isValidDataFrame)
export(isValidLogicalVector)
export(isValidNumericVector)
export(print.fxl)
export(print.fxlsemilog)
export(scr_anno_arrows)
export(scr_anno_brackets)
export(scr_anno_guide_line)
export(scr_anno_rect)
export(scr_bar_support)
export(scr_criterion_lines)
export(scr_cumsum_lines)
export(scr_cumsum_points)
export(scr_label_facet)
export(scr_label_phase)
export(scr_legend)
export(scr_lines)
export(scr_plines)
export(scr_plines_mbd)
export(scr_plot)
export(scr_points)
export(scr_save)
export(scr_title)
export(scr_xlabel)
export(scr_xoverride)
export(scr_ylabel)
export(scr_yoverride)
export(var_map)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rgb)
importFrom(grDevices,svg)
importFrom(grDevices,tiff)
importFrom(grDevices,xy.coords)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,clip)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(rlang,enexpr)
importFrom(rlang,enexprs)
